abacusai.chatllm_task — AbacusAI documentation

# abacusai.chatllm_task

## Classes

`ChatllmTask` | A chatllm task

## Module Contents

class abacusai.chatllm_task.ChatllmTask(client, chatllmTaskId=None, daemonTaskId=None, taskType=None, name=None, instructions=None, lifecycle=None, scheduleInfo=None, externalApplicationId=None, deploymentConversationId=None, sourceDeploymentConversationId=None, enableEmailAlerts=None, email=None, numUnreadTaskInstances=None, computePointsUsed=None, displayMarkdown=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A chatllm task

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - chatllmTaskId (str) – The id of the chatllm task.

    - daemonTaskId (str) – The id of the daemon task.

    - taskType (str) – The type of task (‘chatllm’ or ‘daemon’).

    - name (str) – The name of the chatllm task.

    - instructions (str) – The instructions of the chatllm task.

    - lifecycle (str) – The lifecycle of the chatllm task.

    - scheduleInfo (dict) – The schedule info of the chatllm task.

    - externalApplicationId (str) – The external application id associated with the chatllm task.

    - deploymentConversationId (str) – The deployment conversation id associated with the chatllm task.

    - sourceDeploymentConversationId (str) – The source deployment conversation id associated with the chatllm task.

    - enableEmailAlerts (bool) – Whether email alerts are enabled for the chatllm task.

    - email (str) – The email to send alerts to.

    - numUnreadTaskInstances (int) – The number of unread task instances for the chatllm task.

    - computePointsUsed (int) – The compute points used for the chatllm task.

    - displayMarkdown (str) – The display markdown for the chatllm task.

  chatllm_task_id = None
  daemon_task_id = None
  task_type = None
  name = None
  instructions = None
  lifecycle = None
  schedule_info = None
  external_application_id = None
  deployment_conversation_id = None
  source_deployment_conversation_id = None
  enable_email_alerts = None
  email = None
  num_unread_task_instances = None
  compute_points_used = None
  display_markdown = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict